==> devextreme-22.1.1-alpha-21320-1002.tgz: package/cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js <==
/**
 * DevExtreme (cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js)
 * Version: 22.1.0 (build 21320-1002)
 * Build date: Tue Nov 16 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _strategy_vertical = _interopRequireDefault(require("./strategy_vertical"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var WeekAppointmentRenderingStrategy = function(_VerticalRenderingStr) {
    _inheritsLoose(WeekAppointmentRenderingStrategy, _VerticalRenderingStr);

    function WeekAppointmentRenderingStrategy() {
        return _VerticalRenderingStr.apply(this, arguments) || this
    }
    var _proto = WeekAppointmentRenderingStrategy.prototype;
    _proto.isApplyCompactAppointmentOffset = function() {
        if (this.isAdaptive && 0 === this._getMaxAppointmentCountPerCellByType()) {
            return false
        }
        return this.supportCompactDropDownAppointments()
    };
    return WeekAppointmentRenderingStrategy
}(_strategy_vertical.default);
var _default = WeekAppointmentRenderingStrategy;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-22.2.1-alpha-22313-0309.tgz: package/cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js <==
/**
 * DevExtreme (cjs/ui/scheduler/appointments/rendering_strategies/strategy_week.js)
 * Version: 22.2.0 (build 22313-0309)
 * Build date: Wed Nov 09 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _strategy_vertical = _interopRequireDefault(require("./strategy_vertical"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var WeekAppointmentRenderingStrategy = function(_VerticalRenderingStr) {
    _inheritsLoose(WeekAppointmentRenderingStrategy, _VerticalRenderingStr);

    function WeekAppointmentRenderingStrategy() {
        return _VerticalRenderingStr.apply(this, arguments) || this
    }
    var _proto = WeekAppointmentRenderingStrategy.prototype;
    _proto.isApplyCompactAppointmentOffset = function() {
        if (this.isAdaptive && 0 === this._getMaxAppointmentCountPerCellByType()) {
            return false
        }
        return this.supportCompactDropDownAppointments()
    };
    return WeekAppointmentRenderingStrategy
}(_strategy_vertical.default);
var _default = WeekAppointmentRenderingStrategy;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;
